import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

// Dimensions and settings for the cat face
const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;
const eyeOffsetX = 90;
const eyeOffsetY = 100;
const eyeRadius = 50;
const mouthWidth = 10;
const mouthRadius = 140;

// Mouth arc created using D3
const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

// Butterfly component for drawing simple butterflies
const Butterfly = ({ x, y }) => (
  <g transform={`translate(${x}, ${y})`}>
    {/* Butterfly wings */}
    <ellipse rx="20" ry="10" fill="red" />
    <ellipse
      rx="20"
      ry="10"
      fill="red"
      transform="scale(-1,1)"
    />
    {/* Butterfly body */}
    <rect
      x="-2"
      y="-10"
      width="4"
      height="20"
      fill="black"
    />
    {/* Butterfly antennae */}
    <line
      x1="-2"
      y1="-10"
      x2="-5"
      y2="-20"
      stroke="black"
      strokeWidth="2"
    />
    <line
      x1="2"
      y1="-10"
      x2="5"
      y2="-20"
      stroke="black"
      strokeWidth="2"
    />
  </g>
);

// Main App component including the cat face and butterflies
const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      {/* Cat face */}
      <circle
        r={centerY - strokeWidth / 2}
        fill="white"
        stroke="black"
        strokeWidth={strokeWidth}
      />
      <circle
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        strokeWidth="7"
      />
      <circle
        cx={eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius}
        fill="white"
        stroke="black"
        strokeWidth="7"
      />
      <circle
        cx={eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius / 2}
        fill="green"
        stroke="green"
      />
      <circle
        cx={-eyeOffsetX}
        cy={-eyeOffsetY}
        r={eyeRadius / 2}
        fill="blue"
        stroke="red"
      />
      {/* Cat mouth */}
      <path d={mouthArc()} fill="black" />
    </g>
    {/* Butterflies */}
    <Butterfly x={100} y={100} />
    <Butterfly x={850} y={100} />
    <Butterfly x={100} y={400} />
    <Butterfly x={850} y={400} />
  </svg>
);

// Rendering the App component to the DOM
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
